From 405568fee47099e759ee2f0aadcaf004c3375bec Mon Sep 17 00:00:00 2001
From: Michael Hoennig <michael@hoennig.de>
Date: Sun, 28 Apr 2019 08:11:41 +0200
Subject: [PATCH] fine-tuning pitest config and increasing threshold

---
 build.gradle                             | 11 +++++++----
 gradle/wrapper/gradle-wrapper.properties |  3 ++-
 2 files changed, 9 insertions(+), 5 deletions(-)

diff --git a/gradle/wrapper/gradle-wrapper.properties b/gradle/wrapper/gradle-wrapper.properties
index e0b3fb8d..10affbb8 100644
--- a/gradle/wrapper/gradle-wrapper.properties
+++ b/gradle/wrapper/gradle-wrapper.properties
@@ -1,5 +1,6 @@
+#Sun Apr 28 06:46:48 CEST 2019
 distributionBase=GRADLE_USER_HOME
 distributionPath=wrapper/dists
-distributionUrl=https\://services.gradle.org/distributions/gradle-4.10.2-bin.zip
 zipStoreBase=GRADLE_USER_HOME
 zipStorePath=wrapper/dists
+distributionUrl=https\://services.gradle.org/distributions/gradle-4.10.2-all.zip
diff --git a/build.gradle b/build.gradle
index ef380de5..25caf852 100644
--- a/build.gradle
+++ b/build.gradle
@@ -240,14 +240,17 @@ pitest {
                         'org.hostsharing.hsadminng.**Criteria',
                         'org.hostsharing.hsadminng.**MapperImpl',
                         'org.hostsharing.hsadminng.aop.logging.*',
+                        'org.hostsharing.hsadminng.web.rest.vm.*',
+                        'org.hostsharing.hsadminng.security.jwt.TokenProvider',
                         'org.hostsharing.hsadminng.web.api.*' // API helpers, not the API itself
                       ]
     threads = 2
 
-    // Do not set these limit lower! 90% each might sound good, but keep in mind:
-    // 90%*90% means that ~81% of the code are properly covered by automated tests.
-    mutationThreshold = 90
-    coverageThreshold = 90
+    // Do not set these limit lower! 96% each might sound great, but keep in mind:
+    // 91%*91% means that ~8% of the code are NOT properly covered by automated tests
+    // (100%-94%*96% = ~8%). Not counting defects which come through missing code :-)
+    coverageThreshold = 94
+    mutationThreshold = 96
 
     outputFormats = ['XML', 'HTML']
     timestampedReports = false